pub struct CommandBuffer { /* private fields */ }Expand description
A GPU command buffer that records and submits work to the GPU.
Implementations
Sourceimpl CommandBuffer
impl CommandBuffer
Sourcepub fn new(label: impl Into<String>) -> Self
pub fn new(label: impl Into<String>) -> Self
Create a new, empty command buffer in the Recording state.
Sourcepub fn record(&mut self, entry: CommandEntry)
pub fn record(&mut self, entry: CommandEntry)
Sourcepub fn finish(&mut self) -> bool
pub fn finish(&mut self) -> bool
Finish recording and transition the buffer to Executable.
Returns false if the buffer was not in Recording state.
Sourcepub fn submit(&mut self) -> Option<Vec<CommandEntry>>
pub fn submit(&mut self) -> Option<Vec<CommandEntry>>
Simulate submission to the GPU queue.
Returns the list of submitted commands (for testing / inspection) and
transitions the buffer to Pending.
Returns None if the buffer is not Executable.
Sourcepub fn begin(&mut self) -> bool
pub fn begin(&mut self) -> bool
Begin a fresh recording pass after a reset.
Returns false if the buffer was not in Reset state.
Sourcepub fn command_count(&self) -> usize
pub fn command_count(&self) -> usize
Number of recorded commands.
Sourcepub fn state(&self) -> CommandBufferState
pub fn state(&self) -> CommandBufferState
Current state of the buffer.
Sourcepub fn total_estimated_cost(&self) -> f32
pub fn total_estimated_cost(&self) -> f32
Total estimated GPU cost of all recorded commands.