pub fn dispatch_1d(count: u32, wg_size: u32) -> DispatchGridExpand description
Calculate the dispatch grid needed to cover count elements with
threads of size wg_size in the X dimension.
pub fn dispatch_1d(count: u32, wg_size: u32) -> DispatchGridCalculate the dispatch grid needed to cover count elements with
threads of size wg_size in the X dimension.