dispatch_2d

Function dispatch_2d 

pub fn dispatch_2d(
    width: u32,
    height: u32,
    wg_x: u32,
    wg_y: u32,
) -> DispatchGrid
Calculate the dispatch grid needed to cover a width × height image with a planar workgroup of size (wg_x, wg_y).