pub fn compute_dispatch(
element_count: u32,
workgroup_size: u32,
strategy: DispatchStrategy,
) -> IndirectDispatchArgsExpand description
Compute dispatch arguments from an element count and strategy.
pub fn compute_dispatch(
element_count: u32,
workgroup_size: u32,
strategy: DispatchStrategy,
) -> IndirectDispatchArgsCompute dispatch arguments from an element count and strategy.