pub struct DenoiseKernel { /* private fields */ }Expand description
Denoise kernel configuration for use with the kernels module.
Implementations
Sourceimpl DenoiseKernel
impl DenoiseKernel
Sourcepub fn new(algorithm: DenoiseAlgorithm) -> Self
pub fn new(algorithm: DenoiseAlgorithm) -> Self
Create a new denoise kernel with the given algorithm.
Sourcepub fn bilateral(sigma_spatial: f32, sigma_range: f32) -> Self
pub fn bilateral(sigma_spatial: f32, sigma_range: f32) -> Self
Create a bilateral filter denoise kernel.
Sourcepub fn nlm(h: f32, patch_radius: u32, search_radius: u32) -> Self
pub fn nlm(h: f32, patch_radius: u32, search_radius: u32) -> Self
Create an NLM denoise kernel.
Sourcepub fn apply(
&self,
device: &GpuDevice,
input: &[u8],
output: &mut [u8],
width: u32,
height: u32,
) -> Result<()>
pub fn apply( &self, device: &GpuDevice, input: &[u8], output: &mut [u8], width: u32, height: u32, ) -> Result<()>
Apply this kernel to an RGBA image.
Errors
Returns an error if buffer sizes are invalid or the operation fails.
Sourcepub fn algorithm(&self) -> DenoiseAlgorithm
pub fn algorithm(&self) -> DenoiseAlgorithm
Get the algorithm used by this kernel.
Sourcepub fn estimate_gflops(&self, width: u32, height: u32) -> f64
pub fn estimate_gflops(&self, width: u32, height: u32) -> f64
Estimate GFLOP for width × height frame at this algorithm.