pub struct CommandQueue { /* private fields */ }Expand description
Command queue wrapper with additional functionality
Implementations
Sourceimpl CommandQueue
impl CommandQueue
Sourcepub fn submit_single(&self, command_buffer: CommandBuffer) -> SubmissionIndex
pub fn submit_single(&self, command_buffer: CommandBuffer) -> SubmissionIndex
Sourcepub fn submit_many(
&self,
command_buffers: Vec<CommandBuffer>,
) -> SubmissionIndex
pub fn submit_many( &self, command_buffers: Vec<CommandBuffer>, ) -> SubmissionIndex
Sourcepub fn submit_encoder(&self, encoder: CommandEncoder) -> SubmissionIndex
pub fn submit_encoder(&self, encoder: CommandEncoder) -> SubmissionIndex
Sourcepub fn write_buffer(&self, buffer: &Buffer, offset: u64, data: &[u8])
pub fn write_buffer(&self, buffer: &Buffer, offset: u64, data: &[u8])
Write data directly to a buffer
This is a convenience method that bypasses the staging buffer and directly writes to the destination buffer.
Arguments
buffer- Target bufferoffset- Offset in bytesdata- Data to write
Sourcepub fn queue_type(&self) -> QueueType
pub fn queue_type(&self) -> QueueType
Get the queue type