pub struct QueueManager { /* private fields */ }Expand description
Queue manager for multi-queue support
Implementations
Sourceimpl QueueManager
impl QueueManager
Sourcepub fn new(device: &GpuDevice) -> Self
pub fn new(device: &GpuDevice) -> Self
Create a new queue manager
Note: In wgpu, we typically have a single queue that handles all operations. This abstraction provides a logical separation for different workload types.
Sourcepub fn compute(&self) -> &CommandQueue
pub fn compute(&self) -> &CommandQueue
Get the compute queue
Sourcepub fn transfer(&self) -> &CommandQueue
pub fn transfer(&self) -> &CommandQueue
Get the transfer queue
Sourcepub fn graphics(&self) -> &CommandQueue
pub fn graphics(&self) -> &CommandQueue
Get the graphics queue
Sourcepub fn get_queue(&self, queue_type: QueueType) -> &CommandQueue
pub fn get_queue(&self, queue_type: QueueType) -> &CommandQueue
Get a queue by type