AttachmentFormat

Enum AttachmentFormat 

pub enum AttachmentFormat {
    Rgba8Unorm,
    Rgba16Float,
    Rgba32Float,
    Depth32FloatStencil8,
    Depth32Float,
    Depth24PlusStencil8,
}
Pixel format of a render attachment.

Variants



Rgba8Unorm

8-bit per channel RGBA.



Rgba16Float

16-bit per channel RGBA (HDR).



Rgba32Float

32-bit per channel RGBA (HDR).



Depth32FloatStencil8

32-bit depth, 8-bit stencil.



Depth32Float

32-bit float depth only.



Depth24PlusStencil8

24-bit depth, 8-bit stencil.

Implementations

Source

impl AttachmentFormat

pub fn has_depth(&self) -> bool

Returns true when this format contains a depth component.

pub fn has_stencil(&self) -> bool

Returns true when this format contains a stencil component.

pub fn bytes_per_texel(&self) -> u32

Returns the number of bytes per texel.