pub struct AttachmentConfig {
pub format: AttachmentFormat,
pub load_op: LoadOp,
pub store_op: StoreOp,
pub sample_count: u32,
pub label: Option<String>,
}Expand description
Configuration for a single attachment within a render pass.
Fields
format: AttachmentFormatPixel format.
load_op: LoadOpOperation at the start of the pass.
store_op: StoreOpOperation at the end of the pass.
sample_count: u32Optional MSAA sample count (1 = no MSAA).
label: Option<String>Debug label.
Implementations
Sourceimpl AttachmentConfig
impl AttachmentConfig
Sourcepub fn new(format: AttachmentFormat, load_op: LoadOp, store_op: StoreOp) -> Self
pub fn new(format: AttachmentFormat, load_op: LoadOp, store_op: StoreOp) -> Self
Creates an attachment configuration.
Sourcepub fn has_depth(&self) -> bool
pub fn has_depth(&self) -> bool
Returns true when this attachment is a depth (or depth/stencil) attachment.
Sourcepub fn is_multisampled(&self) -> bool
pub fn is_multisampled(&self) -> bool
Returns true when MSAA is enabled (sample count > 1).
Sourcepub fn with_sample_count(self, count: u32) -> Self
pub fn with_sample_count(self, count: u32) -> Self
Sets the MSAA sample count.
Sourcepub fn with_label(self, label: impl Into<String>) -> Self
pub fn with_label(self, label: impl Into<String>) -> Self
Attaches a debug label.