pub struct RenderPassBuilder { /* private fields */ }Expand description
Fluent builder for RenderPassConfig.
Implementations
Sourceimpl RenderPassBuilder
impl RenderPassBuilder
Sourcepub fn add_color_attachment(self, attachment: AttachmentConfig) -> Self
pub fn add_color_attachment(self, attachment: AttachmentConfig) -> Self
Appends a color attachment.
Sourcepub fn set_depth_attachment(
self,
attachment: AttachmentConfig,
) -> Result<Self, String>
pub fn set_depth_attachment( self, attachment: AttachmentConfig, ) -> Result<Self, String>
Sets the depth/stencil attachment.
Returns an error string if the attachment format does not contain depth.
Sourcepub fn with_label(self, label: impl Into<String>) -> Self
pub fn with_label(self, label: impl Into<String>) -> Self
Sets a debug label for the render pass.
Sourcepub fn build(self) -> Result<RenderPassConfig, String>
pub fn build(self) -> Result<RenderPassConfig, String>
Consumes the builder and returns the RenderPassConfig.
Returns an error if no color attachments have been added.