pub struct Fence { /* private fields */ }Expand description
Fence for CPU-GPU synchronization
A fence allows the CPU to wait for GPU operations to complete.
Implementations
Sourceimpl Fence
impl Fence
Sourcepub fn signal(&self)
pub fn signal(&self)
Signal the fence
This should be called after submitting GPU commands that you want to wait for.
Sourcepub fn wait(&self)
pub fn wait(&self)
Wait for the fence to be signaled
This will block the current thread until the GPU has completed the operations that were submitted before the fence was signaled.
Sourcepub fn wait_timeout(&self, timeout: Duration) -> bool
pub fn wait_timeout(&self, timeout: Duration) -> bool
Sourcepub fn is_signaled(&self) -> bool
pub fn is_signaled(&self) -> bool
Check if the fence is signaled without blocking