pub struct TextureDescriptor {
pub width: u32,
pub height: u32,
pub format: TextureFormat,
pub mip_levels: u8,
pub array_layers: u16,
}Expand description
Descriptor for a single GPU texture
Fields
width: u32Width in texels
height: u32Height in texels
format: TextureFormatTexel format
mip_levels: u8Number of mip levels (1 = base level only)
array_layers: u16Number of array layers (1 = single texture)
Implementations
Sourceimpl TextureDescriptor
impl TextureDescriptor
Sourcepub fn new(width: u32, height: u32, format: TextureFormat) -> Self
pub fn new(width: u32, height: u32, format: TextureFormat) -> Self
Create a simple 2-D texture with no mip chain and a single layer
Sourcepub fn size_bytes(&self) -> usize
pub fn size_bytes(&self) -> usize
Total size in bytes for the full mip chain and all array layers
Each successive mip level has half the dimensions of the previous. Minimum mip size is 1×1.
Sourcepub fn total_pixels(&self) -> u64
pub fn total_pixels(&self) -> u64
Total number of texels in the base mip level (ignoring arrays / mips)