pub struct AtlasConfig {
pub width: u32,
pub height: u32,
pub padding: u32,
}Expand description
Configuration for a TextureAtlas.
Fields
width: u32Total width of the backing atlas texture in texels.
height: u32Total height of the backing atlas texture in texels.
padding: u32Number of transparent texels added around each sub-image to prevent bleeding during bilinear sampling.