pub enum VertexBufferError {
StrideMismatch {
stride: usize,
data_len: usize,
},
Empty,
}Expand description
Errors that can occur when working with a VertexBuffer.
Variants
StrideMismatch
The raw byte data length is not a multiple of the layout stride.
Empty
The buffer is empty and no vertices could be retrieved.