pub enum BarrierKind {
MemoryReadAfterWrite,
ExecutionOnly,
Full,
}Expand description
Type of pipeline barrier.
Variants
MemoryReadAfterWrite
Ensures all memory writes are visible to subsequent reads.
ExecutionOnly
Ensures all dispatches before the barrier complete before new ones begin.
Full
Full pipeline barrier (most restrictive, highest cost).