pub struct LensDistortionCorrector { /* private fields */ }Expand description
Lens distortion corrector.
Removes lens distortion from RGBA frames using the Brown-Conrady model.
Implementations
Sourceimpl LensDistortionCorrector
impl LensDistortionCorrector
Sourcepub fn new(params: LensDistortionParams) -> Self
pub fn new(params: LensDistortionParams) -> Self
Create a new corrector with the given lens parameters.
Sourcepub fn undistort_rgba(
&self,
src: &[u8],
src_w: u32,
src_h: u32,
dst: &mut [u8],
) -> Result<()>
pub fn undistort_rgba( &self, src: &[u8], src_w: u32, src_h: u32, dst: &mut [u8], ) -> Result<()>
Remove lens distortion from an RGBA frame.
For each output pixel the undistortion mapping is applied to find the source location, which is sampled bilinearly.
Errors
Returns an error if src and dst buffer sizes don’t match the
declared dimensions.