CommandQueue

Struct CommandQueue 

pub struct CommandQueue { /* private fields */ }
Command queue wrapper with additional functionality

Implementations

Source

impl CommandQueue

pub fn new(device: &GpuDevice, queue_type: QueueType) -> Self

Create a new command queue

pub fn submit_single(&self, command_buffer: CommandBuffer) -> SubmissionIndex

Submit a single command buffer to the queue

Arguments
  • command_buffer - Command buffer to submit
Returns

Submission index for synchronization

pub fn submit_many( &self, command_buffers: Vec<CommandBuffer>, ) -> SubmissionIndex

Submit multiple command buffers to the queue

Arguments
  • command_buffers - Command buffers to submit
Returns

Submission index for synchronization

pub fn submit_encoder(&self, encoder: CommandEncoder) -> SubmissionIndex

Submit commands created by an encoder

Arguments
  • encoder - Command encoder to finish and submit
Returns

Submission index for synchronization

pub fn write_buffer(&self, buffer: &Buffer, offset: u64, data: &[u8])

Write data directly to a buffer

This is a convenience method that bypasses the staging buffer and directly writes to the destination buffer.

Arguments
  • buffer - Target buffer
  • offset - Offset in bytes
  • data - Data to write
pub fn wait(&self)

Wait for all pending operations on this queue to complete

pub fn queue_type(&self) -> QueueType

Get the queue type

pub fn queue(&self) -> &Arc<Queue>

Get the underlying WGPU queue