Module shader_cache

Module shader_cache 

GPU shader cache management.

This module provides compiled shader storage, cache eviction, and version tracking to avoid redundant shader compilation work.

Structs

CompiledShader
A compiled shader blob stored in the cache.
GpuShaderCache
In-process GPU shader cache.
ShaderCacheStats
Statistics for the shader cache.
ShaderVersion
Version identifier for a compiled shader.

Enums

EvictionPolicy
Eviction policy for the shader cache.

Functions

age_of
Estimate the age of a SystemTime relative to now.
hash_source
Compute a simple 64-bit FNV-1a hash of a byte slice.