GPU shader cache management.
This module provides compiled shader storage, cache eviction, and version tracking to avoid redundant shader compilation work.
Structs
- Compiled
Shader - A compiled shader blob stored in the cache.
- GpuShader
Cache - In-process GPU shader cache.
- Shader
Cache Stats - Statistics for the shader cache.
- Shader
Version - Version identifier for a compiled shader.
Enums
- Eviction
Policy - Eviction policy for the shader cache.
Functions
- age_of
- Estimate the age of a
SystemTimerelative to now. - hash_
source - Compute a simple 64-bit FNV-1a hash of a byte slice.