Fence

Struct Fence 

pub struct Fence { /* private fields */ }
Fence for CPU-GPU synchronization

A fence allows the CPU to wait for GPU operations to complete.

Implementations

Source

impl Fence

pub fn new(device: &GpuDevice) -> Self

Create a new fence

pub fn signal(&self)

Signal the fence

This should be called after submitting GPU commands that you want to wait for.

pub fn wait(&self)

Wait for the fence to be signaled

This will block the current thread until the GPU has completed the operations that were submitted before the fence was signaled.

pub fn wait_timeout(&self, timeout: Duration) -> bool

Wait for the fence with a timeout

Arguments
  • timeout - Maximum time to wait
Returns

True if the fence was signaled within the timeout, false otherwise.

pub fn is_signaled(&self) -> bool

Check if the fence is signaled without blocking

pub fn reset(&self)

Reset the fence to unsignaled state

pub fn timestamp(&self) -> Option<u64>

Get the timestamp when the fence was signaled (in nanoseconds)