TexturePool

Struct TexturePool 

pub struct TexturePool { /* private fields */ }
A pool of GPU textures backed by a fixed memory budget

Implementations

Source

impl TexturePool

pub fn new(max_gb: f64) -> Self

Create a pool with a budget of max_gb gigabytes

pub fn allocate(&mut self, desc: TextureDescriptor) -> Option<usize>

Allocate a texture in the pool

Returns Some(handle) on success, or None if the budget is exceeded.

pub fn allocate_with_lru_eviction( &mut self, desc: TextureDescriptor, ) -> Option<usize>

Allocate a texture, evicting the LRU slot if the budget is exceeded.

Returns Some(handle) on success, or None if all live textures are too large to free enough space for the new allocation.

pub fn lru_handle(&self) -> Option<usize>

Return the handle of the least-recently-used allocated texture, or None if the pool is empty.

pub fn touch(&mut self, handle: usize)

Update the access timestamp of handle to mark it as recently used.

pub fn free(&mut self, id: usize)

Free a texture by handle

pub fn utilization(&self) -> f64

Utilisation in [0.0, 1.0]

pub fn live_count(&self) -> usize

Number of live (allocated) textures

pub fn allocated_bytes(&self) -> usize

Currently allocated bytes

pub fn max_bytes(&self) -> usize

Pool capacity in bytes